@@ -51,7 +51,7 @@
 #define ONLINE_CB_RETRY 3
 #define ONLINE_CB_RETRY_MAX_DELAY 4
 
-#define OFFLINE_TIMEOUT_RANDOM_OFFSET 30
+#define OFFLINE_TIMEOUT_RANDOM_OFFSET_DEFAULT 30
 #define OFFLINE_TIMEOUT_DEFAULT 60
 #define OFFLINE_TIMEOUT_MAX_DEFAULT 3600
 
@@ -134,10 +134,30 @@ static int get_offline_timeout_max(struct be_ctx *ctx)
     return offline_timeout_max;
 }
 
+static int get_offline_timeout_random_offset(struct be_ctx *ctx)
+{
+    int offline_timeout_random_offset;
+    errno_t ret;
+
+    ret = confdb_get_int(ctx->cdb, ctx->conf_path,
+                         CONFDB_DOMAIN_OFFLINE_TIMEOUT_RANDOM_OFFSET,
+                         OFFLINE_TIMEOUT_RANDOM_OFFSET_DEFAULT,
+                         &offline_timeout_random_offset);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_CONF_SETTINGS,
+              "Failed to get refresh_max_random_offset from confdb. "
+              "Will use %d seconds.\n", OFFLINE_TIMEOUT_RANDOM_OFFSET_DEFAULT);
+        offline_timeout_random_offset = OFFLINE_TIMEOUT_RANDOM_OFFSET_DEFAULT;
+    }
+
+    return offline_timeout_random_offset;
+}
+
 void be_mark_offline(struct be_ctx *ctx)
 {
     int offline_timeout;
     int offline_timeout_max;
+    int offline_timeout_random_offset;
     errno_t ret;
 
     DEBUG(SSSDBG_TRACE_INTERNAL, "Going offline!\n");
@@ -152,13 +172,14 @@ void be_mark_offline(struct be_ctx *ctx)
 
         offline_timeout = get_offline_timeout(ctx);
         offline_timeout_max = get_offline_timeout_max(ctx);
+        offline_timeout_random_offset = get_offline_timeout_random_offset(ctx);
 
         ret = be_ptask_create_sync(ctx,
                                    ctx,
                                    offline_timeout,
                                    offline_timeout,
                                    offline_timeout,
-                                   OFFLINE_TIMEOUT_RANDOM_OFFSET,
+                                   offline_timeout_random_offset,
                                    offline_timeout,
                                    offline_timeout_max,
                                    try_to_go_online,
@@ -270,7 +291,7 @@ static errno_t be_check_online_request(struct be_ctx *be_ctx)
     reset_fo(be_ctx);
 
     req = dp_req_send(be_ctx, be_ctx->provider, NULL, "Online Check",
-                      DPT_ID, DPM_CHECK_ONLINE, 0, NULL, NULL);
+                      0, NULL, DPT_ID, DPM_CHECK_ONLINE, 0, NULL, NULL);
     if (req == NULL) {
         return ENOMEM;
     }
@@ -463,7 +484,10 @@ be_register_monitor_iface(struct sbus_connection *conn, struct be_ctx *be_ctx)
             SBUS_SYNC(METHOD, sssd_service, rotateLogs, data_provider_logrotate, be_ctx)
         ),
         SBUS_SIGNALS(SBUS_NO_SIGNALS),
-        SBUS_PROPERTIES(SBUS_NO_PROPERTIES)
+        SBUS_PROPERTIES(
+            SBUS_SYNC(GETTER, sssd_service, debug_level, generic_get_debug_level, NULL),
+            SBUS_SYNC(SETTER, sssd_service, debug_level, generic_set_debug_level, NULL)
+        )
     );
 
     struct sbus_path paths[] = {
@@ -699,8 +723,8 @@ int main(int argc, const char *argv[])
     struct main_context *main_ctx;
     char *confdb_path;
     int ret;
-    uid_t uid;
-    gid_t gid;
+    uid_t uid = 0;
+    gid_t gid = 0;
 
     struct poptOption long_options[] = {
         POPT_AUTOHELP
@@ -738,13 +762,10 @@ int main(int argc, const char *argv[])
 
     poptFreeContext(pc);
 
-    DEBUG_INIT(debug_level);
-
     /* set up things like debug, signals, daemonization, etc. */
     debug_log_file = talloc_asprintf(NULL, "sssd_%s", be_domain);
     if (!debug_log_file) return 2;
-
-    sss_set_logger(opt_logger);
+    DEBUG_INIT(debug_level, opt_logger);
 
     srv_name = talloc_asprintf(NULL, "be[%s]", be_domain);
     if (!srv_name) return 2;
@@ -752,7 +773,7 @@ int main(int argc, const char *argv[])
     confdb_path = talloc_asprintf(NULL, CONFDB_DOMAIN_PATH_TMPL, be_domain);
     if (!confdb_path) return 2;
 
-    ret = server_setup(srv_name, 0, 0, 0, confdb_path, &main_ctx);
+    ret = server_setup(srv_name, false, 0, 0, 0, confdb_path, &main_ctx, false);
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE, "Could not set up mainloop [%d]\n", ret);
         return 2;
