@@ -269,18 +269,30 @@ static void sdap_inherit_basic_options(char **inherit_opt_list,
                                        struct dp_option *subdom_opts)
 {
     int inherit_options[] = {
+        SDAP_SEARCH_TIMEOUT,
+        SDAP_NETWORK_TIMEOUT,
+        SDAP_OPT_TIMEOUT,
+        SDAP_OFFLINE_TIMEOUT,
+        SDAP_ENUM_REFRESH_TIMEOUT,
+        SDAP_ENUM_REFRESH_OFFSET,
         SDAP_PURGE_CACHE_TIMEOUT,
-        SDAP_AD_USE_TOKENGROUPS,
+        SDAP_PURGE_CACHE_OFFSET,
         SDAP_KRB5_KEYTAB,
+        SDAP_KRB5_TICKET_LIFETIME,
+        SDAP_ENUM_SEARCH_TIMEOUT,
+        SDAP_EXPIRE_TIMEOUT,
+        SDAP_EXPIRE_OFFSET,
+        SDAP_IDLE_TIMEOUT,
+        SDAP_AD_USE_TOKENGROUPS,
         SDAP_OPTS_BASIC     /* sentinel */
     };
     int i;
 
     for (i = 0; inherit_options[i] != SDAP_OPTS_BASIC; i++) {
-        dp_option_inherit(inherit_opt_list,
-                          inherit_options[i],
-                          parent_opts,
-                          subdom_opts);
+        dp_option_inherit_match(inherit_opt_list,
+                                inherit_options[i],
+                                parent_opts,
+                                subdom_opts);
     }
 }
 
@@ -661,7 +673,7 @@ errno_t sdap_parse_deref(TALLOC_CTX *mem_ctx,
     const char *orig_dn;
     const char **ocs;
     struct sdap_attr_map *map;
-    int num_attrs;
+    int num_attrs = 0;
     int ret, i, a, mi;
     const char *name;
     size_t len;
@@ -1695,26 +1707,143 @@ int sdap_replace_id(struct sysdb_attrs *entry, const char *attr, id_t val)
     return EOK;
 }
 
-static errno_t
-sdap_get_primary_name(TALLOC_CTX *memctx,
-                      const char *attr_name,
-                      struct sysdb_attrs *attrs,
-                      struct sss_domain_info *dom,
-                      const char **_primary_name)
+static errno_t sdap_get_rdn_multi(TALLOC_CTX *mem_ctx, const char *dn,
+                                  const char *name, char **_val)
+{
+    int ret;
+    size_t c;
+    LDAPDN ldapdn = NULL;
+
+    ret = ldap_str2dn(dn, &ldapdn, LDAP_DN_FORMAT_LDAPV3);
+    if (ret != LDAP_SUCCESS || ldapdn == NULL || ldapdn[0] == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE, "Failed to parse DN [%s].\n", dn);
+        ret = EINVAL;
+        goto done;
+    }
+
+    ret = ENOENT;
+    for (c = 0; ldapdn[0][c] != NULL; c++) {
+        if (strncasecmp(name, ldapdn[0][c]->la_attr.bv_val,
+                        ldapdn[0][c]->la_attr.bv_len) == 0) {
+            *_val = talloc_strndup(mem_ctx, ldapdn[0][c]->la_value.bv_val,
+                                   ldapdn[0][c]->la_value.bv_len);
+            if (*_val == NULL) {
+                DEBUG(SSSDBG_OP_FAILURE, "Failed to copy AVA value.\n");
+                ret = ENOMEM;
+                goto done;
+            }
+            ret = EOK;
+            break;
+        }
+    }
+
+done:
+    ldap_dnfree(ldapdn);
+
+    return ret;
+}
+
+errno_t sdap_get_primary_name(const char *attr_name,
+                              struct sysdb_attrs *attrs,
+                              const char **_primary_name)
 {
     errno_t ret;
     const char *orig_name = NULL;
+    char *rdn_val = NULL;
+    struct ldb_message_element *sysdb_name_el;
+    struct ldb_message_element *orig_dn_el;
+    size_t i;
+    TALLOC_CTX *tmp_ctx = NULL;
 
-    ret = sysdb_attrs_primary_name(dom->sysdb, attrs, attr_name, &orig_name);
-    if (ret != EOK) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "The object has no name attribute\n");
-        return EINVAL;
+    tmp_ctx = talloc_new(NULL);
+    if (!tmp_ctx) {
+        return ENOMEM;
     }
 
+    ret = sysdb_attrs_get_el(attrs,
+                             SYSDB_NAME,
+                             &sysdb_name_el);
+    if (ret != EOK || sysdb_name_el->num_values == 0) {
+        ret = EINVAL;
+        goto done;
+    }
+
+    if (sysdb_name_el->num_values == 1) {
+        /* Entry contains only one name. Just return that */
+        orig_name = (const char *)sysdb_name_el->values[0].data;
+        ret = EOK;
+        goto done;
+    }
+
+    /* Multiple values for name. Check whether one matches the RDN */
+
+    ret = sysdb_attrs_get_el(attrs, SYSDB_ORIG_DN, &orig_dn_el);
+    if (ret) {
+        goto done;
+    }
+    if (orig_dn_el->num_values == 0) {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Original DN is not available.\n");
+        ret = EINVAL;
+        goto done;
+    } else if (orig_dn_el->num_values == 1) {
+        ret = sdap_get_rdn_multi(tmp_ctx,
+                                 (const char *) orig_dn_el->values[0].data,
+                                 attr_name, &rdn_val);
+        if (ret == ENOENT) {
+            DEBUG(SSSDBG_MINOR_FAILURE,
+                  "The entry has multiple names and the RDN attribute does "
+                  "not match. Will use the first value [%s] as fallback.\n",
+                  (const char *)sysdb_name_el->values[0].data);
+            orig_name = (const char *)sysdb_name_el->values[0].data;
+            ret = EOK;
+            goto done;
+        } else if (ret != EOK) {
+            DEBUG(SSSDBG_CRIT_FAILURE, "Could not get rdn from [%s]\n",
+                      (const char *) orig_dn_el->values[0].data);
+            goto done;
+        }
+    } else {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Should not have more than one origDN\n");
+        ret = EINVAL;
+        goto done;
+    }
+
+    for (i = 0; i < sysdb_name_el->num_values; i++) {
+        if (strcasecmp(rdn_val,
+                       (const char *)sysdb_name_el->values[i].data) == 0) {
+            /* This name matches the RDN. Use it */
+            break;
+        }
+    }
+    if (i < sysdb_name_el->num_values) {
+        /* Match was found */
+        orig_name = (const char *)sysdb_name_el->values[i].data;
+    } else {
+        /* If we can't match the name to the RDN, we just have to
+         * throw up our hands. There's no deterministic way to
+         * decide which name is correct.
+         */
+        DEBUG(SSSDBG_CRIT_FAILURE,
+              "Can't match the name to the RDN\n");
+        ret = EINVAL;
+        goto done;
+    }
+
+    ret = EOK;
+
+done:
+    if (ret != EOK) {
+        DEBUG(SSSDBG_CRIT_FAILURE,
+              "Could not determine primary name: [%d][%s]\n",
+                  ret, strerror(ret));
+    }
+    talloc_free(tmp_ctx);
+
     DEBUG(SSSDBG_TRACE_FUNC, "Processing object %s\n", orig_name);
 
-    *_primary_name = talloc_strdup(memctx, orig_name);
-    return EOK;
+    *_primary_name = orig_name;
+
+    return ret;
 }
 
 static errno_t
@@ -1734,7 +1863,7 @@ sdap_get_primary_fqdn(TALLOC_CTX *mem_ctx,
         return ENOMEM;
     }
 
-    ret = sdap_get_primary_name(tmp_ctx, attr_name, attrs, dom, &shortname);
+    ret = sdap_get_primary_name(attr_name, attrs, &shortname);
     if (ret != EOK) {
         goto done;
     }
@@ -1774,17 +1903,93 @@ errno_t sdap_get_group_primary_name(TALLOC_CTX *memctx,
                                  attrs, dom, _group_name);
 }
 
-errno_t sdap_get_netgroup_primary_name(TALLOC_CTX *memctx,
-                                       struct sdap_options *opts,
+errno_t sdap_get_netgroup_primary_name(struct sdap_options *opts,
                                        struct sysdb_attrs *attrs,
-                                       struct sss_domain_info *dom,
                                        const char **_netgroup_name)
 {
-    return sdap_get_primary_name(memctx,
-                                 opts->netgroup_map[SDAP_AT_NETGROUP_NAME].name,
-                                 attrs, dom, _netgroup_name);
+    return sdap_get_primary_name(opts->netgroup_map[SDAP_AT_NETGROUP_NAME].name,
+                                 attrs, _netgroup_name);
 }
 
+static errno_t
+_sdap_get_primary_name_list(struct sss_domain_info *domain,
+                            TALLOC_CTX *mem_ctx,
+                            struct sysdb_attrs **attr_list,
+                            size_t attr_count,
+                            const char *ldap_attr,
+                            bool qualify_names,
+                            char ***name_list)
+{
+    errno_t ret;
+    size_t i, j;
+    char **list;
+    const char *name;
+
+    /* Assume that every entry has a primary name */
+    list = talloc_array(mem_ctx, char *, attr_count+1);
+    if (!list) {
+        return ENOMEM;
+    }
+
+    j = 0;
+    for (i = 0; i < attr_count; i++) {
+        ret = sdap_get_primary_name(ldap_attr, attr_list[i], &name);
+        if (ret != EOK) {
+            DEBUG(SSSDBG_CRIT_FAILURE, "Could not determine primary name\n");
+            /* Skip and continue. Don't advance 'j' */
+            continue;
+        }
+
+        if (qualify_names == false) {
+            list[j] = talloc_strdup(list, name);
+        } else {
+            list[j] = sss_create_internal_fqname(list, name, domain->name);
+        }
+        if (!list[j]) {
+            ret = ENOMEM;
+            goto done;
+        }
+
+        j++;
+    }
+
+    /* NULL-terminate the list */
+    list[j] = NULL;
+
+    *name_list = list;
+
+    ret = EOK;
+
+done:
+    if (ret != EOK) {
+        talloc_free(list);
+    }
+    return ret;
+}
+
+errno_t sdap_get_primary_name_list(struct sss_domain_info *domain,
+                                   TALLOC_CTX *mem_ctx,
+                                   struct sysdb_attrs **attr_list,
+                                   size_t attr_count,
+                                   const char *ldap_attr,
+                                   char ***name_list)
+{
+    return _sdap_get_primary_name_list(domain, mem_ctx, attr_list, attr_count,
+                                       ldap_attr, false, name_list);
+}
+
+errno_t sdap_get_primary_fqdn_list(struct sss_domain_info *domain,
+                                   TALLOC_CTX *mem_ctx,
+                                   struct sysdb_attrs **attr_list,
+                                   size_t attr_count,
+                                   const char *ldap_attr,
+                                   char ***name_list)
+{
+    return _sdap_get_primary_name_list(domain, mem_ctx, attr_list, attr_count,
+                                       ldap_attr, true, name_list);
+}
+
+
 char *sdap_make_oc_list(TALLOC_CTX *mem_ctx, struct sdap_attr_map *map)
 {
     if (map[SDAP_OC_GROUP_ALT].name == NULL) {
