@@ -56,7 +56,7 @@ static void sss_tool_common_opts(struct sss_tool_ctx *tool_ctx,
                                  int *argc, const char **argv)
 {
     poptContext pc;
-    int debug = SSSDBG_DEFAULT;
+    int debug = SSSDBG_TOOLS_DEFAULT;
     int orig_argc = *argc;
     int help = 0;
 
@@ -384,6 +384,7 @@ errno_t sss_tool_popt_ex(struct sss_cmdline *cmdline,
                          void *popt_fn_pvt,
                          const char *fopt_name,
                          const char *fopt_help,
+                         enum sss_tool_opt fopt_require,
                          const char **_fopt,
                          bool *_opt_set)
 {
@@ -401,6 +402,11 @@ errno_t sss_tool_popt_ex(struct sss_cmdline *cmdline,
     bool opt_set;
     int ret;
 
+    /* Set output parameter _fopt to NULL value if present. */
+    if (_fopt != NULL) {
+        *_fopt = NULL;
+    }
+
     /* Create help option string. We always need to append command name since
      * we use POPT_CONTEXT_KEEP_FIRST. */
     if (fopt_name == NULL) {
@@ -440,14 +446,19 @@ errno_t sss_tool_popt_ex(struct sss_cmdline *cmdline,
         }
     }
 
-    /* Parse free option which is always required if requested. */
+    /* Parse free option which is required if requested and fopt_require
+     * is SSS_TOOL_OPT_REQUIRED */
+    opt_set = true;
     fopt = poptGetArg(pc);
     if (_fopt != NULL) {
         if (fopt == NULL) {
-            ERROR("Missing option: %s\n\n", fopt_help);
-            poptPrintHelp(pc, stderr, 0);
-            ret = EINVAL;
-            goto done;
+            if (fopt_require == SSS_TOOL_OPT_REQUIRED) {
+                ERROR("Missing option: %s\n\n", fopt_help);
+                poptPrintHelp(pc, stderr, 0);
+                ret = EINVAL;
+                goto done;
+            }
+            opt_set = false;
         }
 
         /* No more arguments expected. If something follows it is an error. */
@@ -458,7 +469,14 @@ errno_t sss_tool_popt_ex(struct sss_cmdline *cmdline,
             goto done;
         }
 
-        *_fopt = fopt;
+        if (fopt != NULL) {
+            *_fopt = strdup(fopt);
+            if (*_fopt == NULL) {
+                ERROR("Out of memory!");
+                ret = ENOMEM;
+                goto done;
+            }
+        }
     } else if (_fopt == NULL && fopt != NULL) {
         /* Unexpected free argument. */
         ERROR("Unexpected parameter: %s\n\n", fopt);
@@ -467,8 +485,8 @@ errno_t sss_tool_popt_ex(struct sss_cmdline *cmdline,
         goto done;
     }
 
-    opt_set = true;
-    if ((_fopt != NULL && cmdline->argc < 2) || cmdline->argc < 1) {
+    if ((_fopt != NULL && fopt_require == SSS_TOOL_OPT_REQUIRED && cmdline->argc < 2)
+            || cmdline->argc < 1) {
         opt_set = false;
 
         /* If at least one option is required and not provided, print error. */
@@ -489,6 +507,11 @@ errno_t sss_tool_popt_ex(struct sss_cmdline *cmdline,
 done:
     poptFreeContext(pc);
     talloc_free(help);
+    if (ret != EOK && _fopt != NULL) {
+        free(discard_const(*_fopt));
+        *_fopt = NULL;
+    }
+
     return ret;
 }
 
@@ -499,7 +522,8 @@ errno_t sss_tool_popt(struct sss_cmdline *cmdline,
                       void *popt_fn_pvt)
 {
     return sss_tool_popt_ex(cmdline, options, require_option,
-                            popt_fn, popt_fn_pvt, NULL, NULL, NULL, NULL);
+                            popt_fn, popt_fn_pvt, NULL, NULL,
+                            SSS_TOOL_OPT_REQUIRED, NULL, NULL);
 }
 
 int sss_tool_main(int argc, const char **argv,
@@ -512,7 +536,6 @@ int sss_tool_main(int argc, const char **argv,
 
     uid = getuid();
     if (uid != 0) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "Running under %d, must be root\n", uid);
         ERROR("%1$s must be run as root\n", argv[0]);
         return EXIT_FAILURE;
     }
@@ -572,3 +595,25 @@ done:
 
     return ret;
 }
+
+errno_t sss_tool_connect_to_confdb(TALLOC_CTX *ctx, struct confdb_ctx **cdb_ctx)
+{
+    int ret;
+    char *confdb_path = NULL;
+
+    confdb_path = talloc_asprintf(ctx, "%s/%s", DB_PATH, CONFDB_FILE);
+    if (confdb_path == NULL) {
+        DEBUG(SSSDBG_CRIT_FAILURE,
+              "Could not allocate memory for confdb path\n");
+        return ENOMEM;
+    }
+
+    ret = confdb_init(ctx, cdb_ctx, confdb_path);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_CRIT_FAILURE,
+              "Could not initialize connection to the confdb\n");
+    }
+
+    talloc_free(confdb_path);
+    return ret;
+}
