@@ -195,8 +195,18 @@ struct main_context {
     pid_t parent_pid;
 };
 
+struct sbus_request;
+
 errno_t server_common_rotate_logs(struct confdb_ctx *confdb,
                                   const char *conf_entry);
+errno_t generic_get_debug_level(TALLOC_CTX *mem_ctx,
+                                struct sbus_request *sbus_req,
+                                void *pvt_data,
+                                uint32_t *_debug_level);
+errno_t generic_set_debug_level(TALLOC_CTX *mem_ctx,
+                                struct sbus_request *sbus_req,
+                                void *pvt_data,
+                                uint32_t new_debug_level);
 int die_if_parent_died(void);
 int check_pidfile(const char *file);
 int pidfile(const char *file);
@@ -204,7 +214,8 @@ int server_setup(const char *name, bool is_responder,
                  int flags,
                  uid_t uid, gid_t gid,
                  const char *conf_entry,
-                 struct main_context **main_ctx);
+                 struct main_context **main_ctx,
+                 bool allow_sss_loop);
 void server_loop(struct main_context *main_ctx);
 void orderly_shutdown(int status);
 
